@@ -10,5 +10,5 @@ from .lemmatizer import Lemmatizer
 from .pair_checker import PairChecker
 from .dictionary import *
 from .code2vec import *
-from .pdg_parser import PDGParser
-from .verb_helper import VerbHelper
\ No newline at end of file
+from .verb_helper import VerbHelper
+from .dependency_analyzer import DependencyAnalyzer
\ No newline at end of file
