@@ -15,8 +15,11 @@ class CallGraphAnalyzer:
         self.pattern = re.compile(r"(\w):(.*) \((\w)\)(.*)")
 
     def __del__(self):
-        if jpype.isJVMStarted():
-            jpype.shutdownJVM()
+        try:
+            if jpype.isJVMStarted():
+                jpype.shutdownJVM()
+        except Exception:
+            pass
 
     def build_cg(self, path):
         calls = []
