@@ -14,8 +14,11 @@ class DependencyAnalyzer:
         self.PDGBuilder = jpype.JClass('codetoolkit.janalysis.dg.pdg.PDGBuilder')
 
     def __del__(self):
-        if jpype.isJVMStarted():
-            jpype.shutdownJVM()
+        try:
+            if jpype.isJVMStarted():
+                jpype.shutdownJVM()
+        except Exception:
+            pass
 
     def build_cfg(self, code):
         cfgs = self.CFGBuilder.buildWithCode(code)
